import unittest
import sys
import os
from xml.dom.minidom import parseString

mydir = os.getcwd()
sys.path.append(mydir + "/..")
import netcf


ROOT = mydir + "/testroot"

if not os.path.exists(ROOT + '/etc/sysconfig/network-scripts'):
    os.makedirs(ROOT + '/etc/sysconfig/network-scripts')
    

class TestNetcf(unittest.TestCase):
    
    @classmethod
    def setUpClass(cls):
        "initial setup"
        TestNetcf.eth0 = """
        <interface type="ethernet" name="eth0">
          <start mode="onboot"/>
          <protocol family="ipv4">
            <ip address="10.1.1.123" prefix="24"/>
          </protocol>
        </interface>"""
    
    @classmethod    
    def tearDownClass(cls):
        "clean up after finish"
        
        os.removedirs(ROOT + '/etc/sysconfig/network-scripts')
        
    def test01define(self):
        "test ncf_define"
        n = netcf.Netcf(root=ROOT)
        #xml = open(mydir + "eth0.xml").read()
        dev = n.define(TestNetcf.eth0)
        self.failUnless(dev == 'eth0')
        
    def test02NumOfInterfaces(self):
        "test ncf_num_interfaces"
        n = netcf.Netcf(ROOT)
        self.failUnless(n.numOfInterfaces() == 1)
        del n
    
    def test03listInterfaces(self):
        "test ncf_list_interfaces"
        n = netcf.Netcf(root=ROOT)
        self.failUnless(n.listInterfaces()[0] == 'eth0')
        
    def test04ifXMLDesc(self):
        "test ncf_if_xml_desc"
        n = netcf.Netcf(root=ROOT)
        xml = n.ifXMLDesc('eth0')
        self.failUnless(isinstance(xml, basestring))
        dom = parseString(xml)
        dev = dom.getElementsByTagName('interface')[0].attributes['name'].value
        self.failUnless(dev == 'eth0')
        
    def test05ifXMLState(self):
        "test ncf_if_xml_state"
        n = netcf.Netcf(root=ROOT)
        xml = n.ifXMLState('eth0')
        self.failUnless(isinstance(xml, basestring))
        dom = parseString(xml)
        dev = dom.getElementsByTagName('interface')[0].attributes['name'].value
        self.failUnless(dev == 'eth0')
    
    @unittest.skip('Skipping ifup')
    def test06ifup(self):
        "test ncf_if_up"
        n = netcf.Netcf(root=ROOT)
        ret = n.ifup('eth0')
        # Ok to fail, need to be root to bring if up
        self.failUnless(ret == -1)

    @unittest.skip('Skipping ifdown')
    def test07ifdown(self):
        "test ncf_if_down"
        n = netcf.Netcf(root=ROOT)
        ret = n.ifdown('eth0')
        # Ok to fail, need to be root to bring if down
        self.failUnless(ret == -1)
    
    def test08ifStatus(self):
        "test ncf_if_status"
        n = netcf.Netcf(root=ROOT)
        ret = n.ifStatus('eth0')
        self.failUnless(ret > 0 )
    
    def test09ifMacString(self):
        "test ncf_if_mac_string"
        n = netcf.Netcf(root=ROOT)
        ret = n.ifMacString('eth0')
        self.failUnless(ret == None )
 
    def test10undefine(self):
        "test ncf_undefine"
        n = netcf.Netcf(root=ROOT)
        dev = n.undefine('eth0')
        self.failUnless(dev == 0 )   

def getsuite():
    suite = unittest.TestSuite()
    suite = unittest.makeSuite(TestNetcf, 'test')
    return suite

if __name__ == "__main__":
    __testRunner = unittest.TextTestRunner(verbosity=10)
    __result = __testRunner.run(getsuite())
    sys.exit(not __result.wasSuccessful())

__author__ = "Lars Sjostrom <lars.sjostrom@redhat.com>"